items — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# items

IDs of the items that can be displayed in Eric’s inventory. The image specifications for each item are defined in the [Inventory] section of the ini file.

`items.` `FROG` = 'FROG'

  Captured frog.

`items.` `MOUSE` = 'MOUSE'

  Captured mouse.

`items.` `SAFE_KEY` = 'SAFE_KEY'

  Safe key.

`items.` `SHERRY_PISTOL` = 'SHERRY_PISTOL'

  Water pistol containing sherry.

`items.` `STINKBOMBS1` = 'STINKBOMBS1'

  One stinkbomb.

`items.` `STINKBOMBS2` = 'STINKBOMBS2'

  Two stinkbombs.

`items.` `STINKBOMBS3` = 'STINKBOMBS3'

  Three stinkbombs.

`items.` `STOREROOM_KEY` = 'STOREROOM_KEY'

  Science Lab storeroom key.

`items.` `WATER_PISTOL` = 'WATER_PISTOL'

  Water pistol containing water.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »